@@ -10,9 +10,9 @@
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -21,13 +21,7 @@
 #include <iostream>
 #include <gio/gio.h>
 
-#ifndef G_OS_WIN32
-# include <gio/gunixinputstream.h>
-# include <gio/gunixoutputstream.h>
-# include <gio/gunixconnection.h>
-#endif
-
-int main(int, char**)
+int main (int argc, char** argv)
 {
   g_type_init ();
 
@@ -51,11 +45,6 @@ int main(int, char**)
             << get_defs(G_TYPE_FILTER_INPUT_STREAM)
             << get_defs(G_TYPE_FILTER_OUTPUT_STREAM)
 
-#ifndef G_OS_WIN32
-            << get_defs(G_TYPE_UNIX_INPUT_STREAM)
-            << get_defs(G_TYPE_UNIX_OUTPUT_STREAM)
-#endif
-
             << get_defs(G_TYPE_INPUT_STREAM)
             << get_defs(G_TYPE_LOADABLE_ICON)
             << get_defs(G_TYPE_MEMORY_INPUT_STREAM)
@@ -72,27 +61,6 @@ int main(int, char**)
 
             << get_defs(G_TYPE_VOLUME_MONITOR)
 
-            // network IO classes
-            << get_defs(G_TYPE_INET_ADDRESS)
-            << get_defs(G_TYPE_INET_SOCKET_ADDRESS)
-            << get_defs(G_TYPE_SOCKET_ADDRESS)
-            << get_defs(G_TYPE_SOCKET_ADDRESS_ENUMERATOR)
-            << get_defs(G_TYPE_SOCKET_CONNECTABLE)
-            << get_defs(G_TYPE_SRV_TARGET)
-            << get_defs(G_TYPE_RESOLVER)
-            << get_defs(G_TYPE_NETWORK_ADDRESS)
-            << get_defs(G_TYPE_NETWORK_SERVICE)
-            << get_defs(G_TYPE_SOCKET)
-            << get_defs(G_TYPE_SOCKET_CLIENT)
-            << get_defs(G_TYPE_SOCKET_CONNECTION)
-            << get_defs(G_TYPE_TCP_CONNECTION)
-#ifndef G_OS_WIN32
-            << get_defs(G_TYPE_UNIX_CONNECTION)
-#endif
-            << get_defs(G_TYPE_SOCKET_LISTENER)
-            << get_defs(G_TYPE_SOCKET_SERVICE)
-            << get_defs(G_TYPE_THREADED_SOCKET_SERVICE)
-
             << std::endl;
   
   return 0;
